@@ -130,7 +130,7 @@ int Num_matrix_astype_Sprimme(void *x, PRIMME_INT m, PRIMME_INT n,
       ldy0 = (ldy ? *ldy : 1);
    }
 
-   if (do_copy) {
+   if (do_copy && x != NULL) {
       CHKERR(Num_copy_Tmatrix_Sprimme(x, xt, m, n, ldx, y0, ldy0, ctx));
    }
 
@@ -142,7 +142,6 @@ int Num_matrix_astype_Sprimme(void *x, PRIMME_INT m, PRIMME_INT n,
 }
 
 #ifdef USE_HOST
-
 #ifdef USE_DOUBLE
 
 TEMPLATE_PLEASE
@@ -197,7 +196,7 @@ int Num_matrix_astype_iprimme(void *x, PRIMME_INT m, PRIMME_INT n,
       ldy0 = (ldy ? *ldy : 1);
    }
 
-   if (do_copy) {
+   if (do_copy && x != NULL) {
       CHKERR(Num_copy_Tmatrix_iprimme(x, xt, m, n, ldx, y0, ldy0, ctx));
    }
 
@@ -209,6 +208,7 @@ int Num_matrix_astype_iprimme(void *x, PRIMME_INT m, PRIMME_INT n,
 }
 
 #endif /* USE_DOUBLE */
+#endif /* USE_HOST */
 
 /******************************************************************************
  * Function Num_copy_matrix_astype - copy the matrix x into y.
@@ -267,17 +267,19 @@ int Num_copy_matrix_astype_Sprimme(void *x, PRIMME_INT xm0, PRIMME_INT xn0,
          xt, m, n, ldx, &((SCALAR *)y)[ym0 + ldy * yn0], ldy, ctx);
 }
 
- /******************************************************************************
+
+/******************************************************************************
  * Function Num_sizeof_Sprimme - Return the size of an element with the given
  *    type.
  *
  * INPUT/OUTPUT PARAMETERS
  * ---------------------------
  * t    Type
+ * s    returned size of the type in bytes
  *
  * RETURN
  * ------
- * int  Size of the type in bytes
+ * int  error code
  *
  ******************************************************************************/
 
@@ -308,6 +310,52 @@ int Num_sizeof_Sprimme(primme_op_datatype t, size_t *s) {
    return 0;
 }
 
+/******************************************************************************
+ * Function Num_machine_epsilon_Sprimme - Return the machine epsilon of the
+ *    type.
+ *
+ * INPUT/OUTPUT PARAMETERS
+ * ---------------------------
+ * t    Type
+ * eps  The returned machine epsilon
+ *
+ * RETURN
+ * ------
+ * int  error code
+ *
+ ******************************************************************************/
+
+TEMPLATE_PLEASE
+int Num_machine_epsilon_Sprimme(primme_op_datatype t, double *eps) {
+
+   /* Replace primme_op_default */
+
+   if (t == primme_op_default) t = PRIMME_OP_SCALAR;
+   
+   /* Call the function that t has the type of the SCALAR */
+
+   if (t != PRIMME_OP_SCALAR) {
+      switch(t) {
+#ifdef SUPPORTED_HALF_TYPE
+      case primme_op_half:   return Num_machine_epsilon_Shprimme(t, eps);
+#endif
+#ifndef PRIMME_WITHOUT_FLOAT
+      case primme_op_float:  return Num_machine_epsilon_Ssprimme(t, eps);
+#endif
+      case primme_op_double: return Num_machine_epsilon_Sdprimme(t, eps);
+#ifdef PRIMME_WITH_NATIVE_COMPLEX_QUAD
+      case primme_op_quad:   return Num_machine_epsilon_Sqprimme(t, eps);
+#endif
+      default: return PRIMME_FUNCTION_UNAVAILABLE;
+      }
+   }
+
+   if (eps) *eps = MACHINE_EPSILON;
+
+   return 0;
+}
+
+#ifdef USE_HOST
 
 /******************************************************************************
  * Function Num_copy_matrix_conj - Copy the matrix x' into y
